measuretools.multiply_contents_of_measures_in_expr
==================================================

.. autofunction:: abjad.tools.measuretools.multiply_contents_of_measures_in_expr.multiply_contents_of_measures_in_expr
